@@ -25,6 +25,15 @@ def minkowski_deviation(x: np.ndarray, order=2) -> np.float64:
     ----------
     x : array-like.
 
+    Returns
+    -------
+    result : np.float64
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> conaction.estimators.minkowski_deviation(np.arange(10))
+    5.338539126015656
     '''
     result = x - np.mean(x)
     result = np.abs(x)
@@ -55,7 +64,14 @@ def reflective_correlation(X: np.ndarray) -> np.float64:
 
     Examples
     ----------
+    >>> import numpy as np
+    >>> data = np.arange(100).reshape(10,10)
+    >>> reflective_correlation(data)
+    0.9995245464170066
     '''
+    if X.dtype != np.float64:
+        X = X.astype(np.float64)
+    
     numerator = np.prod(X, axis=1)
     numerator = np.sum(numerator)
     denominator = np.abs(X)
@@ -88,6 +104,10 @@ def pearson_correlation(X: np.ndarray) -> np.float64:
 
     Examples
     ----------
+    >>> import numpy as np
+    >>> data = np.arange(100).reshape(10,10)
+    >>> pearson_correlation(data)
+    0.9999999999999978
     '''
     transform = X - np.mean(X, axis=0)
     r = reflective_correlation(transform)
@@ -114,6 +134,10 @@ def circular_correlation(X: np.ndarray) -> np.float64:
 
     Examples
     ----------
+    >>> import numpy as np
+    >>> data = np.arange(100).reshape(10,10)
+    >>> circular_correlation(data)
+    0.9999999999999999
     '''
     transform = X - np.mean(X, axis=0)
     transform = np.sin(transform)
@@ -183,8 +207,8 @@ def angular_disimilarity(X: np.ndarray) -> np.float64:
 # TODO: Implement 
 def correlation_ratio(X: np.ndarray, y: np.ndarray) -> np.float64:
     '''
-    .. warn: Not implemented yet.
-    This function calculates the n-ary correlation ratio of a
+    .. warning: Not implemented yet.
+    This function calculates the multilinear correlation ratio of a
     collection of response variables given their classes. The
     classic Fisher's correlation ratio is a special case.
 
@@ -305,10 +329,10 @@ def taylor_correlation(X: np.ndarray) -> np.float64:
 
     .. math::
 
-        \\frac{1}{\\sqrt{d}} \\sqrt{\\frac{1}{d-1} \\sum_{i}^{d} ( \\lambda_i \\bar{\\lambda})^2 }
+        \\frac{1}{\\sqrt{d}} \\sqrt{\\frac{1}{d-1} \\sum_{i}^{d} ( \\lambda_i -  \\bar{\\lambda})^2 }
 
     where :math:`d` is the number of variables, :math:`\lambda_1, \cdots, \lambda_d` are the eigenvalues of
-    the correlation matrix for a given set of variables, and :math:`\bar{\lambda}` is the mean of those eigenvalue.
+    the correlation matrix for a given set of variables, and :math:`\\bar{\\lambda}` is the mean of those eigenvalues.
     Thus Taylor's multi-way correlation coefficient is a rescaling of the Bessel-corrected standard deviation of the
     eigenvalues of the correlation matrix of the set of variables.
     '''
@@ -328,10 +352,11 @@ def trencevski_melceski_correlation(X: np.ndarray, Y: np.ndarray) -> np.float64:
 
     Parameters
     ----------
-        X: array_like
-            m x n data matrix
-        Y: array_like
-            m x n data matrix
+    X: array_like
+        m x n data matrix
+    Y: array_like
+        m x n data matrix
+
     Returns
     ----------
         : float
@@ -350,18 +375,27 @@ def trencevski_melceski_correlation(X: np.ndarray, Y: np.ndarray) -> np.float64:
 
 def wang_zheng_correlation(X: np.ndarray) -> np.float64:
     '''
+
+    Parameters
+    ----------
+    X : array-like
+        m x n data matrix
+
+    Returns
+    -------
+    result : np.float64
+            Unsigned correlation coefficient.
+
     References
     ----------
-    .. [1] ArXiv:1401.4827v6
+    .. [1] Wang, Jianji. Zheng, Nanning. 2014. "Measures of Correlation for Multiple Variables", https://arxiv.org/abs/1401.4827
+
+    Notes
+    -----
+    The complement of this statistic is the unsigned incorrelation coefficient.
     '''
     result = X.T
     result = np.corrcoef(result)
     result = np.linalg.det(result)
     result = 1 - result
     return result
-
-if __name__ == '__main__':
-    x = np.random.normal(size=100)
-    y = np.random.normal(size=100)
-    X = np.random.normal(size=100*3).reshape(100,3)
-    
